==> eiffelstudio-18.07.10.1981.tar: F_code/C33/ql1616.c <==
/*
 * Code for class QL_METRIC_GENERIC_BASIC_SCOPE_INFO
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ql1616.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {QL_METRIC_GENERIC_BASIC_SCOPE_INFO}.make */
void F2172_24745 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLR(5,tr5);
	RTLR(6,arg1);
	RTLIU(7);
	
	RTEAA("make", 2171, Current, 0, 1, 24873);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNSMART(eif_final_id(Y21779,Y21779_gen_type,dftype,2166).id);
	F1_29(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = F4508_52561(RTCW(tr1));
	{
		EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,3840,0,0xFFFF};
		EIF_TYPE typres0;
		typarr0[3] = dftype;
		
		typres0 = eif_compound_id(dftype, typarr0);
		tr2 = RTLNTS(typres0.id, 2, 0);
	}
	((EIF_TYPED_VALUE *)tr2+1)->it_r = Current;
	RTAR(tr2,Current);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {3998,0xFFF9,1,3840,4845,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr5 = RTLNRF(typres0.id, (EIF_POINTER) __A1616_51_2, (EIF_POINTER) _A1616_51_2, (EIF_POINTER)(F2172_24749),tr2, 1, 1);
	}
	F2669_26960(RTCW(tr1), tr5);
	RTHOOK(3);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(4);
	RTLE;
	RTEE;
}

/* {QL_METRIC_GENERIC_BASIC_SCOPE_INFO}.calculate_function */
EIF_REFERENCE F2172_24747 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {QL_METRIC_GENERIC_BASIC_SCOPE_INFO}.domain_generator */
EIF_REFERENCE F2172_24748 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {QL_METRIC_GENERIC_BASIC_SCOPE_INFO}.evaluate_item */
void F2172_24749 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("evaluate_item", 2171, Current, 0, 1, 24877);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr8_1 = (FUNCTION_CAST(EIF_REAL_64, (EIF_POINTER, EIF_REFERENCE, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(tr2)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(tr2)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(tr2) + _REFACS_1_), arg1);
		;
		tr8_1 = tr8_1;
		F2211_25033(RTCW(tr1), tr8_1);
	} else {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current);
		F2211_25033(RTCW(tr1), (EIF_REAL_64) 1.0);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

void EIF_Minit1616 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-18.11.10.2592.tar: F_code/C33/ql1616.c <==
/*
 * Code for class QL_METRIC_QUANTITY_BASIC_SCOPE_INFO
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ql1616.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {QL_METRIC_QUANTITY_BASIC_SCOPE_INFO}.make */
void F1838_24315 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REFERENCE tr3 = NULL;
	EIF_REFERENCE tr4 = NULL;
	EIF_REFERENCE tr5 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(7);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,tr3);
	RTLR(4,tr4);
	RTLR(5,tr5);
	RTLR(6,arg1);
	RTLIU(7);
	
	RTEAA("make", 1837, Current, 0, 1, 23576);
	RTGC;
	RTHOOK(1);
	tr1 = RTLNSMART(eif_final_id(Y21538,Y21538_gen_type,dftype,1827).id);
	F1_29(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
	tr1 = F4527_52801(RTCW(tr1));
	{
		EIF_TYPE_INDEX typarr0[] = {0xFFF9,1,3860,0,0xFFFF};
		EIF_TYPE typres0;
		typarr0[3] = dftype;
		
		typres0 = eif_compound_id(dftype, typarr0);
		tr2 = RTLNTS(typres0.id, 2, 0);
	}
	((EIF_TYPED_VALUE *)tr2+1)->it_r = Current;
	RTAR(tr2,Current);
	
	{
		static EIF_TYPE_INDEX typarr0[] = {4017,0xFFF9,1,3860,4522,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr5 = RTLNRF(typres0.id, (EIF_POINTER) __A1616_51_2, (EIF_POINTER) _A1616_51_2, (EIF_POINTER)(F1838_24319),tr2, 1, 1);
	}
	F2623_26828(RTCW(tr1), tr5);
	RTHOOK(3);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) arg1;
	RTHOOK(6);
	RTLE;
	RTEE;
}

/* {QL_METRIC_QUANTITY_BASIC_SCOPE_INFO}.calculate_function */
EIF_REFERENCE F1838_24317 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {QL_METRIC_QUANTITY_BASIC_SCOPE_INFO}.domain_generator */
EIF_REFERENCE F1838_24318 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {QL_METRIC_QUANTITY_BASIC_SCOPE_INFO}.evaluate_item */
void F1838_24319 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_REAL_64 tr8_1;
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,arg1);
	RTLIU(4);
	
	RTEAA("evaluate_item", 1837, Current, 0, 1, 23580);
	RTGC;
	RTHOOK(1);
	if ((EIF_BOOLEAN)(*(EIF_REFERENCE *)(Current + _REFACS_1_) != NULL)) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current);
		tr2 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
		tr8_1 = (FUNCTION_CAST(EIF_REAL_64, (EIF_POINTER, EIF_REFERENCE, EIF_REFERENCE)) *(EIF_POINTER *)(RTCW(tr2)+ _PTROFF_4_2_0_3_0_0_))(
			*(EIF_POINTER *)(RTCW(tr2)+ _PTROFF_4_2_0_3_0_1_),
			*(EIF_REFERENCE *)(RTCW(tr2) + _REFACS_1_), arg1);
		;
		tr8_1 = tr8_1;
		F1924_24633(RTCW(tr1), tr8_1);
	} else {
		RTHOOK(3);
		tr1 = *(EIF_REFERENCE *)(Current);
		F1924_24633(RTCW(tr1), (EIF_REAL_64) 1.0);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
}

void EIF_Minit1616 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
